#PBS -l nodes=1:ppn=16:xeon16
#PBS -l walltime=0:25:0
#PBS -o stdout.log
#PBS -e stderr.log
#PBS -N marius

from gpaw import GPAW, PoissonSolver, Mixer, FermiDirac
from gpaw.xc.libvdwxc import LibVDWXC
from gpaw.utilities import h2gpts
from gpaw.utilities.timing import Timer
from ase.optimize.bfgs import BFGS

from ase.io import read

system = read('armchair-c8h2-scs-mp2-cc-pVDZ.xyz')
system.rotate([0, 1, 0], [1, 0, 0])
#system.rotate([0, 0, 1], [1, 0, 0])
system.center(vacuum=5.0)
system.pbc = 1

timer = Timer()
libvdwxc = LibVDWXC(timer=timer)
oldvdw = 'vdW-DF'

#xc = oldvdw
xc = libvdwxc

if xc == libvdwxc:
    name = 'libvdwxc'
elif xc == oldvdw:
    name = 'oldvdw'
else:
    raise ValueError


calc = GPAW(txt='gpaw.%s.txt' % name,
            timer=timer,
            xc=xc,
            occupations=FermiDirac(0.01),
            mixer=Mixer(0.3, 5, 20.0),
            eigensolver='rmm-diis',
            poissonsolver=PoissonSolver(relax='GS'),
            gpts=(160, 96, 72),
            #gpts=h2gpts(0.18, system.get_cell(), idiv=8),
            convergence=dict(density=1e-5),
            nbands='110%',)

system.set_calculator(calc)
#system.get_potential_energy()

opt = BFGS(system, trajectory='opt.traj', logfile='opt.log')

#1e-4 * Hartree / Bohr
opt.run(fmax=0.005)

